@@ -263,7 +263,10 @@ findLocalsList <- function(elist, envir = .BaseEnv) {
         env <- mkHash()
         for (e in elist) walkCode(e, w)
         isloc <- sapply(sf, exists, envir = env, inherits = FALSE)
-        if (nsf == length(locals) || length(sf[isloc] == nsf)) {
+        last.nsf <- nsf
+        sf <- unique(c(locals, sf[isloc]))
+        nsf <- length(sf)
+        if (last.nsf == nsf) {
             vals <- ls(env, all.names = TRUE)
             rdsf <- vals %in% specialSyntaxFuns
             if (any(rdsf))
@@ -271,10 +274,6 @@ findLocalsList <- function(elist, envir = .BaseEnv) {
                                vals[rdsf]))
             return(vals)
         }
-        else {
-            sf <- unique(c(locals, sf[isloc]))
-            nsf <- length(sf)
-        }
     }
 }
 
